"""Pylons application test package

When the test runner finds and executes tests within this directory, this file
will be loaded to setup the test environment.

It registers the root directory of the project in sys.path and pkg_resources,
in case the project hasn't been installed with setuptools. It also initializes
the application via websetup (paster setup-app) with the project's test.ini
configuration file.
"""
import os
import sys
import unittest
import doctest


import pkg_resources
import paste.fixture
import paste.script.appinstall
from paste.deploy import loadapp
from routes import url_for
from sqlalchemy import engine_from_config

__all__ = ['url_for', 'TestController']

here_dir = os.path.dirname(os.path.abspath(__file__))
conf_dir = os.path.dirname(os.path.dirname(here_dir))

sys.path.insert(0, conf_dir)
pkg_resources.working_set.add_entry(conf_dir)
pkg_resources.require('Paste')
pkg_resources.require('PasteScript')

test_file = os.path.join(conf_dir, 'test.ini')
cmd = paste.script.appinstall.SetupCommand('setup-app')
cmd.run([test_file])

from pylons import config
config['pylons.g'].sa_engine = engine_from_config(config, 'sqlalchemy.default.')

from twistit import model

def setUp(test):
    engine = config['pylons.g'].sa_engine
    model.metadata.create_all(bind=engine)

def tearDown(test):
    model.metadata.drop_all()

def application():
    wsgiapp = loadapp('config:test.ini', relative_to=conf_dir)
    test_data = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'data')
    return paste.fixture.TestApp(wsgiapp, 
                                 relative_to=test_data)
